-- DO NOT MODIFY MANUALLY
--
-- This file has been generated with ./generate-spdx-licenses-module.sh.

{-# LANGUAGE OverloadedStrings #-}
module Data.License.SpdxLicenses where
import Data.Text (Text)
import Data.License.Type
licenses :: [(License, Text)]
licenses = [
    (BSD2, "\
\Copyright (c) <year> <owner> . All rights reserved.\n\
\\n\
\Redistribution and use in source and binary forms, with or without modification,\n\
\are permitted provided that the following conditions are met:\n\
\\n\
\1. Redistributions of source code must retain the above copyright notice,\n\
\this list of conditions and the following disclaimer.\n\
\\n\
\2. Redistributions in binary form must reproduce the above copyright notice,\n\
\this list of conditions and the following disclaimer in the documentation\n\
\and/or other materials provided with the distribution.\n\
\\n\
\THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS \"AS IS\"\n\
\AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE\n\
\IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE\n\
\ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE\n\
\LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL\n\
\DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR\n\
\SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER\n\
\CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,\n\
\OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE\n\
\USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.\n\
\")
  , (BSD3, "\
\Copyright (c) <year> <owner> . All rights reserved.\n\
\\n\
\Redistribution and use in source and binary forms, with or without modification,\n\
\are permitted provided that the following conditions are met:\n\
\\n\
\1. Redistributions of source code must retain the above copyright notice,\n\
\this list of conditions and the following disclaimer.\n\
\\n\
\2. Redistributions in binary form must reproduce the above copyright notice,\n\
\this list of conditions and the following disclaimer in the documentation\n\
\and/or other materials provided with the distribution.\n\
\\n\
\3. Neither the name of the copyright holder nor the names of its contributors\n\
\may be used to endorse or promote products derived from this software without\n\
\specific prior written permission.\n\
\\n\
\THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS \"AS IS\"\n\
\AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE\n\
\IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE\n\
\ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE\n\
\LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL\n\
\DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR\n\
\SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER\n\
\CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,\n\
\OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE\n\
\USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.\n\
\")
  , (BSD4, "\
\Copyright (c) <year> <owner> . All rights reserved.\n\
\\n\
\Redistribution and use in source and binary forms, with or without modification,\n\
\are permitted provided that the following conditions are met:\n\
\\n\
\1. Redistributions of source code must retain the above copyright notice,\n\
\this list of conditions and the following disclaimer.\n\
\\n\
\2. Redistributions in binary form must reproduce the above copyright notice,\n\
\this list of conditions and the following disclaimer in the documentation\n\
\and/or other materials provided with the distribution.\n\
\\n\
\3. All advertising materials mentioning features or use of this software must\n\
\display the following acknowledgement:\n\
\\n\
\   This product includes software developed by the organization .\n\
\\n\
\4. Neither the name of the copyright holder nor the names of its contributors\n\
\may be used to endorse or promote products derived from this software without\n\
\specific prior written permission.\n\
\\n\
\THIS SOFTWARE IS PROVIDED BY COPYRIGHT HOLDER \"AS IS\" AND ANY EXPRESS OR IMPLIED\n\
\WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY\n\
\AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL COPYRIGHT\n\
\HOLDER BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,\n\
\OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE\n\
\GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)\n\
\HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT\n\
\LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY\n\
\OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH\n\
\DAMAGE.\n\
\")
  , (ISC, "\
\ISC License\n\
\\n\
\Copyright (c) 2004-2010 by Internet Systems Consortium, Inc. (\"ISC\")\n\
\\n\
\Copyright (c) 1995-2003 by Internet Software Consortium\n\
\\n\
\Permission to use, copy, modify, and /or distribute this software for any\n\
\purpose with or without fee is hereby granted, provided that the above copyright\n\
\notice and this permission notice appear in all copies.\n\
\\n\
\THE SOFTWARE IS PROVIDED \"AS IS\" AND ISC DISCLAIMS ALL WARRANTIES WITH REGARD\n\
\TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS.\n\
\IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL\n\
\DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,\n\
\WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING\n\
\OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.\n\
\")
  , (MIT, "\
\MIT License\n\
\\n\
\Copyright (c) <year> <copyright holders>\n\
\\n\
\Permission is hereby granted, free of charge, to any person obtaining a copy\n\
\of this software and associated documentation files (the \"Software\"), to deal\n\
\in the Software without restriction, including without limitation the rights\n\
\to use, copy, modify, merge, publish, distribute, sublicense, and/or sell\n\
\copies of the Software, and to permit persons to whom the Software is furnished\n\
\to do so, subject to the following conditions:\n\
\\n\
\The above copyright notice and this permission notice shall be included in\n\
\all copies or substantial portions of the Software.\n\
\\n\
\THE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\n\
\IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS\n\
\FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS\n\
\OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,\n\
\WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF\n\
\OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.\n\
\")
  ]
